<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>HelloWorld</name>
    <message>
        <source>Hello World:</source>
        <translation>Γεια σου κόσμε:</translation>
    </message>
    <message>
        <source>Display Text Configuration</source>
        <translation>Εμφάνιση Ρυθμίσεων Κειμένου</translation>
    </message>
    <message>
        <source>Edit HTML</source>
        <translation>Επεξεργασία HTML</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Display simple text. A debugging/sample widget.</source>
        <translation>Εμφάνιση απλού κειμένου. Ένα γραφικό συστατικό αποσφαλμάτωσης.</translation>
    </message>
</context>
</TS>